local threatbar = CreateFrame("StatusBar", "ThreatBar", UIParent)
threatbar:SetHeight(35)
threatbar:SetWidth(200)
threatbar:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
threatbar:EnableMouse(true)
threatbar:SetMovable(true)
threatbar:SetResizable(true)
threatbar:SetUserPlaced(true)
threatbar:SetClampedToScreen( true )
threatbar:SetMaxResize(500,125);
threatbar:SetMinResize(125,16);
threatbar:RegisterForDrag("LeftButton");
threatbar:SetScript("OnDragStart", function(s) 
	if not UnitAffectingCombat("player") then
		if IsAltKeyDown() then s:StartMoving() 
		elseif IsShiftKeyDown() then s:StartSizing()
		end 
	end
end)
threatbar:SetScript("OnDragStop", function(s) s:StopMovingOrSizing() end)
threatbar:SetScript("OnEnter", function(s) 
	if not UnitAffectingCombat("player") then
		GameTooltip:SetOwner(s, "ANCHOR_TOP")
        GameTooltip:AddLine("Basic Threat Bar", 0, 1, 0.5, 1, 1, 1)
        GameTooltip:AddLine("Hold down SHIFT to resize.", 1, 1, 1, 1, 1, 1)
		GameTooltip:AddLine("Hold down ALT to move.", 1, 1, 1, 1, 1, 1)
        GameTooltip:AddLine("Type /btb hide to hide bar out of combat.", 1, 1, 1, 1, 1, 1)
		GameTooltip:AddLine("Type /btb show to leave visible.", 1, 1, 1, 1, 1, 1)
		GameTooltip:AddLine("Right click for configuration.", 1, 1, 1, 1, 1, 1)
		GameTooltip:Show()
	end
end)
threatbar:SetScript("OnLeave", function(s)
GameTooltip:Hide()
end)

threatbar:RegisterEvent("UNIT_THREAT_SITUATION_UPDATE")
threatbar:RegisterEvent("UNIT_THREAT_LIST_UPDATE")
threatbar:RegisterEvent("PLAYER_TARGET_CHANGED")
threatbar:RegisterEvent("PARTY_MEMBERS_CHANGED")
threatbar:RegisterEvent("PLAYER_LOGIN")
threatbar:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")

threatbar:SetMinMaxValues(0, 100)
threatbar:SetValue(0)

local font1 = threatbar:CreateFontString("UnitName", "ARTWORK", "GameFontWhite")
font1:SetPoint("TOP", threatbar, "TOP", 0, 15)

local font2 = threatbar:CreateFontString("Percent", "OVERLAY", "GameFontWhite")
font2:SetPoint("CENTER", threatbar, "CENTER", 0, 0)

--local icon = threatbar:CreateTexture("Icon", "OVERLAY")
--icon:SetTexture("Interface\\LFGFrame\\UI-LFG-ICON-PORTRAITROLES")
--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("TANK"))
--icon:SetPoint("TOPLEFT", threatbar, "TOPLEFT", 0, 15)
--icon:SetHeight(14)
--icon:SetWidth(14)
--icon:Hide()


SLASH_ThreatBar1 = "/btb";
local function handler(msg, editbox)
	if (msg=="show") then
		threatbar:Show()
		hidden = nil
	elseif (msg=="hide") then
		threatbar:Hide()
		hidden = true
	end
end
SlashCmdList["ThreatBar"] = handler;

local fademiActive = fademiActive -- set values
local tempthreat = {}--tempthreat -- set values
local currenttarget = currenttarget -- set values


local function GetLastThreat(mobId)
local targetGUID = UnitGUID("target")
if UnitCanAttack("player", mobId) then
	tempthreat[UnitGUID(mobId)] = select(5, UnitDetailedThreatSituation("player", mobId))
	if targetGUID == UnitGUID(mobId) then
		currenttarget = tempthreat[UnitGUID(mobId)]
	end
end
end

local function StoreThreat()
	if GetNumPartyMembers() > 0 or GetNumRaidMembers() > 0 then
		if GetNumRaidMembers() > 0 then
			for i = 1, GetNumRaidMembers() do
				GetLastThreat("raidtarget"..i)
				GetLastThreat("raidpettarget"..i)
				GetLastThreat("raidtargettarget"..i)
				GetLastThreat("raidpettargettarget"..i)
			end
		else
			for i = 1, GetNumPartyMembers() do
				GetLastThreat("partytarget"..i)
				GetLastThreat("partypettarget"..i)
				GetLastThreat("partytargettarget"..i)
				GetLastThreat("partypettargettarget"..i)
			end
		end

	end
	GetLastThreat("target")
	GetLastThreat("pettarget")
	GetLastThreat("targettarget")
	GetLastThreat("focus")
	GetLastThreat("focustarget")
	GetLastThreat("mouseover")
	GetLastThreat("mouseovertarget")

end

local function GetThreat(unitId, mobId)
	local _, _, threatpct, _, _ = UnitDetailedThreatSituation(unitId, mobId)
	if not threatpct then threatpct = 0 end
	return floor(threatpct)
end

local function GetThreatStatus(unitId, mobId)
	local _,status,_,_, _ = UnitDetailedThreatSituation(unitId, mobId)
	return status
end

local function GetTank(unitId, mobId)
	local isTanking,_,_,_, _ = UnitDetailedThreatSituation(unitId, mobId)
	if not isTanking then isTanking = 0 end
	return isTanking
end

local function GetThreatValue(unitId, mobId)
	local _, _, _, _, threatvalue = UnitDetailedThreatSituation(unitId, mobId)
	if not threatvalue then threatvalue = 0 end
	return threatvalue
end

local function GetClassColor(unit)
	local unitClass, englishClass = UnitClass(unit)
	local classColor = "ff848484" --Not needed?
	if englishClass == "DEATHKNIGHT" then
		classColor = "ffC41F3B"
		
	elseif englishClass == "DRUID" then
		classColor = "ffFF7D0A"
	
	elseif englishClass == "HUNTER" then
		classColor = "ffABD473"
	
	elseif englishClass == "MAGE" then
		classColor = "ff69CCF0"
	
	elseif englishClass == "PALADIN" then
		classColor = "ffF58CBA"
	
	elseif englishClass == "PRIEST" then
		classColor = "ffFFFFFF"
	
	elseif englishClass == "ROGUE" then
		classColor = "ffFFF569"
	
	elseif englishClass == "SHAMAN" then
		classColor = "ff2459FF"
	
	elseif englishClass == "WARLOCK" then
		classColor = "ff9482C9"
	
	elseif englishClass == "WARRIOR" then
		classColor = "ffC79C6E"
	end
	return classColor
end

local function UpdateDisplay()
	font1:SetText("")
	font2:SetText("")
	--icon:Hide()
	threatbar:SetValue(0)
	threatbar:SetBackdropColor(0, 0, 0, .5)
	local status = nil
	local highUnit = ""
	local unitThreat = 0
	local highThreat = 0
	local tankName = nil
	local unitThreatValue = 0
	local playerThreatValue = 0
	local partynum = GetNumPartyMembers()
	local raidnum = GetNumRaidMembers()
	
	if hidden == true  and not status then -- hide frame
		threatbar:Hide()
	end
	if (partynum == 0 and raidnum == 0) and UnitCanAttack("player", "target") and not(UnitIsDead("target") or UnitIsFriend("player", "target") or UnitPlayerControlled("target")) -- Solo Target
	then			
		status = GetThreatStatus("player", "target")
		threatpct = GetThreat("player", "target")
		playerThreatValue = GetThreatValue("player", "target")
		if HasPetUI() then
			unitThreatValue = GetThreatValue("pet", "target")
			highThreat = GetThreat("pet", "target")
			highUnit = UnitName("pet")
			highUnitColor = GetClassColor("pet")
			unitTanking = GetTank("pet", "target")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	elseif (partynum == 0 and raidnum == 0) and UnitCanAttack("player", "targettarget") and not (UnitCanAttack("player", "target") or UnitIsDead("targettarget") or UnitIsFriend("player", "targettarget") or UnitPlayerControlled("targettarget")) -- Solo Target of Target
	then
		status = GetThreatStatus("player", "targettarget")
		threatpct = GetThreat("player", "targettarget")
		playerThreatValue = GetThreatValue("player", "targettarget")
		if HasPetUI() then
			unitThreatValue = GetThreatValue("pet", "targettarget")
			highThreat = GetThreat("pet", "targettarget")
			highUnit = UnitName("pet")
			highUnitColor = GetClassColor("pet")
			unitTanking = GetTank("pet", "targettarget")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	elseif (raidnum > 0) and UnitCanAttack("player", "target") and not (UnitIsDead("target") or UnitIsFriend("player", "target") or UnitPlayerControlled("target")) --Raid Target
	then 
		status = GetThreatStatus("player", "target")
		threatpct = GetThreat("player", "target")
		playerThreatValue = GetThreatValue("player", "target")
		for i = 1, (raidnum -1) do
			unitThreat = GetThreat("raid"..i, "target") 	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("raid"..i)
					highUnitColor = GetClassColor("raid"..i)
					unitThreatValue = GetThreatValue("raid"..i, "target")
				end
			unitThreat = GetThreat("raidpet"..i, "target")	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("raidpet"..i)
					highUnitColor = GetClassColor("pet")
					unitThreatValue = GetThreatValue("raidpet"..i, "target")
				end
			unitThreat = GetThreat("pet", "target")
				if unitThreat > highThreat then
					highThreat = unitThreat
					highUnit = UnitName("pet")
					highUnitColor = GetClassColor("pet")
					unitThreatValue = GetThreatValue("pet", "target")
				end
			unitTanking = GetTank("raid"..i, "target")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("raid"..i)
				tankName = UnitName("raid"..i)
			end
			unitTanking = GetTank("raidpet"..i, "target")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("raidpet"..i)
				tankName = UnitName("raidpet"..i)
			end
			unitTanking = GetTank("pet", "target")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	elseif (raidnum > 0) and UnitCanAttack("player", "targettarget") and not (UnitCanAttack("player", "target") or UnitIsDead("targettarget") or UnitIsFriend("player", "targettarget") or UnitPlayerControlled("targettarget")) --Raid Target of Target
	then
		status = GetThreatStatus("player", "targettarget")
		threatpct = GetThreat("player", "targettarget")	
		playerThreatValue = GetThreatValue("player", "targettarget")
		for i = 1, (raidnum -1) do
			unitThreat = GetThreat("raid"..i, "targettarget") 	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("raid"..i)
					highUnitColor = GetClassColor("raid"..i)
					unitThreatValue = GetThreatValue("raid"..i, "targettarget")
				end
			unitThreat = GetThreat("raidpet"..i, "targettarget")	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("raidpet"..i)
					highUnitColor = GetClassColor("pet")
					unitThreatValue = GetThreatValue("raidpet"..i, "targettarget")
				end
			unitThreat = GetThreat("pet", "targettarget")
				if unitThreat > highThreat then
					highThreat = unitThreat
					highUnit = UnitName("pet")
					highUnitColor = GetClassColor("pet")
					unitThreatValue = GetThreatValue("pet", "targettarget")
				end
			unitTanking = GetTank("raid"..i, "targettarget")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("raid"..i)
				tankName = UnitName("raid"..i)
			end
			unitTanking = GetTank("raidpet"..i, "targettarget")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("raidpet"..i)
				tankName = UnitName("raidpet"..i)
			end
			unitTanking = GetTank("pet", "targettarget")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	elseif (partynum > 0) and UnitCanAttack("player", "target") and not (UnitIsDead("target") or UnitIsFriend("player", "target") or UnitPlayerControlled("target")) -- Party Target
	then 
		status = GetThreatStatus("player", "target")
		threatpct = GetThreat("player", "target")
		playerThreatValue = GetThreatValue("player", "target")
		for i = 1, partynum do
			unitThreat = GetThreat("party"..i, "target") 	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("party"..i)
					highUnitColor = GetClassColor("party"..i)
					unitThreatValue = GetThreatValue("party"..i, "target")
				end
			unitThreat = GetThreat("partypet"..i, "target")	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("partypet"..i)
					highUnitColor = GetClassColor("partypet"..i)
					unitThreatValue = GetThreatValue("partypet"..i, "target")
				end
			unitThreat = GetThreat("pet", "target")
				if unitThreat > highThreat then
					highThreat = unitThreat
					highUnit = UnitName("pet")
					highUnitColor = GetClassColor("pet")
					unitThreatValue = GetThreatValue("pet", "target")
				end
			unitTanking = GetTank("party"..i, "target")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("party"..i)
				tankName = UnitName("party"..i)
			end
			unitTanking = GetTank("partypet"..i, "target")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("partypet"..i)
				tankName = UnitName("partypet"..i)
			end
			unitTanking = GetTank("pet", "target")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	elseif (partynum > 0) and UnitCanAttack("player", "targettarget") and not (UnitCanAttack("player", "target") or UnitIsDead("targettarget") or UnitIsFriend("player", "targettarget") or UnitPlayerControlled("targettarget")) --Party Target of Target
	then
		status = GetThreatStatus("player", "targettarget")
		threatpct = GetThreat("player", "targettarget")
		playerThreatValue = GetThreatValue("player", "targettarget")
		for i = 1, partynum do
			unitThreat = GetThreat("party"..i, "targettarget") 	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("party"..i)
					highUnitColor = GetClassColor("party"..i)
					unitThreatValue = GetThreatValue("party"..i, "targettarget")
				end
			unitThreat = GetThreat("partypet"..i, "targettarget")	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("partypet"..i)
					highUnitColor = GetClassColor("partypet"..i)
					unitThreatValue = GetThreatValue("partypet"..i, "targettarget")
				end
			unitThreat = GetThreat("pet", "targettarget")
				if unitThreat > highThreat then
					highThreat = unitThreat
					highUnit = UnitName("pet")
					highUnitColor = GetClassColor("pet")
					unitThreatValue = GetThreatValue("pet", "targettarget")
				end
			unitTanking = GetTank("party"..i, "targettarget")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("party"..i)
				tankName = UnitName("party"..i)
			end
			unitTanking = GetTank("partypet"..i, "targettarget")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("partypet"..i)
				tankName = UnitName("partypet"..i)
			end
			unitTanking = GetTank("pet", "target")
			if unitTanking == 1 then
				unitTankingColor = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	end
	if status then -- show frame
		
		if hidden == true and not threatbar:IsShown() then
			threatbar:Show()
		end
	end
	if status == 0
	then
		--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
		font2:SetText(string.format("%d %%", threatpct ))
		threatbar:SetValue(threatpct)
		threatbar:SetStatusBarColor(0, 1, 0, 1)
		
		if tankName
		then
			--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("TANK"))
			--icon:Show()
			threatValuediff = ((unitThreatValue - playerThreatValue) / 100000 )
			font1:SetText(string.format("|c%s%s|r", unitTankingColor, tankName ))
			font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, threatpct ))
			threatbar:SetValue(threatpct)
			if currenttarget then -- display temporary threat bar
				threatValuediff = ((unitThreatValue - currenttarget) / 100000 )
				tempthreatpct = floor((currenttarget / unitThreatValue) * 100)
				font1:SetText(string.format("|c%s%s|r", unitTankingColor, tankName ))
				font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, tempthreatpct ))
				threatbar:SetValue(tempthreatpct)
				threatbar:SetStatusBarColor(.5, .5, 1, 1)
			end
		end
	elseif status == 1
	then
		--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
		font2:SetText(string.format("%d %%", threatpct ))
		threatbar:SetValue(threatpct)
		threatbar:SetStatusBarColor(1, 1, 0, 1)
		
		if tankName
		then
			--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("TANK"))
			--icon:Show()
			threatValuediff = ((unitThreatValue - playerThreatValue) / 100000 )
			font1:SetText(string.format("|c%s%s|r", unitTankingColor, tankName ))
			font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, threatpct ))
			threatbar:SetValue(threatpct)
			if currenttarget then -- display temporary threat bar
				threatValuediff = ((unitThreatValue - currenttarget) / 100000 )
				tempthreatpct = floor((currenttarget / unitThreatValue) * 100)
				font1:SetText(string.format("|c%s%s|r", unitTankingColor, tankName ))
				font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, tempthreatpct ))
				threatbar:SetValue(tempthreatpct)
				threatbar:SetStatusBarColor(.5, .5, 1, 1)
			end
		end
	elseif status == 2
	then
		--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
		font2:SetText("WEAK AGGRO!")
		threatbar:SetValue(threatpct)
		threatbar:SetStatusBarColor(1, .5, 0, 1)
		
		if highThreat ~= 0
		then
			--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
			--icon:Show()
			threatValuediff = ((playerThreatValue - unitThreatValue) / 100000 )
			threatdiff = (threatpct - highThreat)
			font1:SetText(string.format("|c%s%s|r", highUnitColor, highUnit ))
			font2:SetText(string.format("%2.1fk | %s %%", threatValuediff, threatdiff ))
			threatbar:SetValue(threatdiff)
			threatbar:SetBackdropColor(1, .5, 0, .4)
			if currenttarget then -- display temporary threat bar
				threatValuediff = ((unitThreatValue - currenttarget) / 100000 )
				threatdiff = floor((currenttarget / unitThreatValue) * 100) - highThreat
				font1:SetText(string.format("|c%s%s|r", highUnitColor, highUnit ))
				font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, threatdiff ))
				threatbar:SetValue(threatdiff)
				threatbar:SetStatusBarColor(.5, .5, 1, 1)
			end
		end	
	elseif status == 3
	then
		--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
		font2:SetText("AGGRO!")
		threatbar:SetValue(threatpct)
		threatbar:SetStatusBarColor(1, 0, 0, 1)
		
		if highThreat ~= 0
		then
			--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
			--icon:Show()
			threatValuediff = ((playerThreatValue - unitThreatValue) / 100000 )
			threatdiff = (threatpct - highThreat)
			font1:SetText(string.format("|c%s%s|r", highUnitColor, highUnit ))
			font2:SetText(string.format("%2.1fk | %s %%", threatValuediff, threatdiff ))
			threatbar:SetValue(threatdiff)
			threatbar:SetBackdropColor(1, 0, 0, .4)
			if currenttarget then -- display temporary threat bar
				threatValuediff = ((unitThreatValue - currenttarget) / 100000 )
				threatdiff = floor((currenttarget / unitThreatValue) * 100) - highThreat
				font1:SetText(string.format("|c%s%s|r", highUnitColor, highUnit ))
				font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, threatdiff ))
				threatbar:SetValue(threatdiff)
				threatbar:SetStatusBarColor(.5, .5, 1, 1)
			end
		end
	end
end

local function tContains(table, item)
       local index = 1;
       while table[index] do
               if ( item == table[index] ) then
                       return 1;
               end
               index = index + 1;
       end
       return nil;
end


local function eventHandler(self, event, ...)
	if event == "PLAYER_LOGIN" then
		if texture and font and fontsize then
			threatbar:SetStatusBarTexture(texture)
			font1:SetFont(font, fontsize)
			font2:SetFont(font, fontsize)
			threatbar:SetBackdrop({ 
	bgFile = texture,
	insets = {left = 0, right = 0, top = 0, bottom = 0}
})
threatbar:SetBackdropColor(0, 0, 0, .5)
		else
			threatbar:SetStatusBarTexture("Interface\\TARGETINGFRAME\\UI-StatusBar")
			font1:SetFont("Fonts\\FRIZQT__.TTF", 12)
			font2:SetFont("Fonts\\FRIZQT__.TTF", 12)
			threatbar:SetBackdrop({ 
	bgFile = "Interface\\TARGETINGFRAME\\UI-StatusBar",
	insets = {left = 0, right = 0, top = 0, bottom = 0}
})
threatbar:SetBackdropColor(0, 0, 0, .5)
		end
		
	elseif event == "COMBAT_LOG_EVENT_UNFILTERED" then
		local timestamp, eventtype, hideCaster, srcGUID, srcName, srcFlags, srcFlags2, dstGUID, dstName, dstFlags, dstFlags2 = ...
		local targetGUID = UnitGUID("target")
		local damage
		local playerGUID = UnitGUID("player")
		if srcGUID == playerGUID then
		if eventtype == "SPELL_AURA_APPLIED" then
			local spellID = select(12, ...)
			if spellID == 55342 or spellID == 586 --[[or spellID == 1038]] then
				--DEFAULT_CHAT_FRAME:AddMessage("Temp spell casted") --debug message
				fademiActive = true
				StoreThreat()		-- set temp threat to last known threat value
			elseif spellID == 32612 and fademiActive == true then -- Invisibility buff while Mirror Image is active
				wipe(tempthreat)
			end
		elseif eventtype == "SPELL_DAMAGE" or eventtype == "RANGE_DAMAGE" or eventtype == "SPELL_PERIODIC_DAMAGE" then
			if fademiActive == true then
			--DEFAULT_CHAT_FRAME:AddMessage("Detecting damage") --debug message
			damage = select(15, ...)
			
			end
		elseif eventtype == "SWING_DAMAGE" then
			if fademiActive == true then
			damage = select(12, ...)
			
			end
		elseif eventtype == "SPELL_AURA_REMOVED" then
			local spellID = select(12, ...)
			if spellID == 55342 or spellID == 586 --[[or spellID == 1038]] then
				--DEFAULT_CHAT_FRAME:AddMessage("Temp spell expired") --debug message
				wipe(tempthreat) -- clear table
				damage = nil
				fademiActive = nil
				currenttarget = nil
			end	
		end
		if damage then
			tempthreat[dstGUID] = (tempthreat[dstGUID] or 0) + damage * 100
			if targetGUID == dstGUID then
				currenttarget = tempthreat[dstGUID]
			end
		end
		end
	elseif event == "PLAYER_TARGET_CHANGED" then
		local targetGUID = UnitGUID("target")
		if fademiActive == true then
			local intable = tContains(tempthreat, targetGUID)
			if not intable then
				currenttarget = nil
				--DEFAULT_CHAT_FRAME:AddMessage("currentarget set to nil") -- debug message
			end
			for index,value in pairs(tempthreat) do 
				if targetGUID == index then
					currenttarget = value
					--DEFAULT_CHAT_FRAME:AddMessage(tostring(index).." : "..tostring(value)) -- debug message
				
				end
			
			end
		end

		UpdateDisplay()
	else
		UpdateDisplay()
	end
end
threatbar:SetScript("OnEvent", eventHandler)


local function SetTexture(button, arg1)	
	threatbar:SetStatusBarTexture(arg1)
	threatbar:SetBackdrop({ 
	bgFile = arg1,
	insets = {left = 0, right = 0, top = 0, bottom = 0}
})
threatbar:SetBackdropColor(0, 0, 0, .5)
	texture = arg1
end

local function SetFont(button, arg1, arg2)
	if not arg2 then 
	arg2 = fontsize or 12
	end
	if not arg1 then
	arg1 = font or "Fonts\\FRIZQT__.TTF"
	end
	font1:SetFont(arg1, arg2)
	font2:SetFont(arg1, arg2)
	font = arg1
	fontsize = arg2
end

local SkurriFont = CreateFont("Skurri")
SkurriFont:SetFont("Fonts\\SKURRI.TTF", 12)

local ArialNarrowFont = CreateFont("ArialNarrow")
ArialNarrowFont:SetFont("Fonts\\ARIALN.TTF", 12)

local MorpheusFont = CreateFont("Morpheus")
MorpheusFont:SetFont("Fonts\\MORPHEUS.TTF", 12)

local FrizQTTFont = CreateFont("Friz Quadratta TT")
FrizQTTFont:SetFont("Fonts\\FRIZQT__.TTF", 10) --smaller font here otherwise distorts menu pane

 local Test1_Data = {
   ["Bar Texture"] = {
     [1] = {["name"] = "Status Bar";
			["path"] = "Interface\\TARGETINGFRAME\\UI-StatusBar";
			["function"] = SetTexture;},
     [2] = {["name"] = "Barfill 2"; 
			["path"] = "Interface\\TARGETINGFRAME\\BarFill2";
			["function"] = SetTexture;},
	 [3] = {["name"] = "Character Skills"; 
			["path"] = "Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar";
			["function"] = SetTexture;},
	 [4] = {["name"] = "Raid HP"; 
			["path"] = "Interface\\RAIDFRAME\\Raid-Bar-Hp-Fill";
			["function"] = SetTexture;},
	 [5] = {["name"] = "Raid Resource"; 
			["path"] = "Interface\\RAIDFRAME\\Raid-Bar-Resource-Fill";
			["function"] = SetTexture;},
	 [6] = {["name"] = "Archeology"; 
			["path"] = "Interface\\Archeology\\Arch-Progress-Fill";
			["function"] = SetTexture;},
	 [7] = {["name"] = "Status Bar 2";
			["path"] = "Interface\\TARGETINGFRAME\\UI-TargetingFrame-Barfill";
			["function"] = SetTexture;},	
   },
   ["Font Style"] = {
     [1] = {["name"] = "Arial Narrow"; 
			["path"] = "Fonts\\ARIALN.TTF";
			["font"] = ArialNarrowFont;
			["function"] = SetFont;},
	 [2] = {["name"] = "Friz Quadrata TT"; 
			["path"] = "Fonts\\FRIZQT__.TTF";
			["font"] = FrizQTTFont;
			["function"] = SetFont;},
	 [3] = {["name"] = "Morpheus"; 
			["path"] = "Fonts\\MORPHEUS.TTF";
			["font"] = MorpheusFont;
			["function"] = SetFont;},
	 [4] = {["name"] = "Skurri"; 
			["path"] = "Fonts\\SKURRI.TTF";
			["font"] = SkurriFont;
			["function"] = SetFont;},	
   },
   ["Font Size"] = {
     [1] = {["name"] = "10"; 
			["size"] = 10;
			["function"] = SetFont;},
     [2] = {["name"] = "12"; 
			["size"] = 12;
			["function"] = SetFont;},
	 [3] = {["name"] = "14"; 
			["size"] = 14;
			["function"] = SetFont;},
	 [4] = {["name"] = "16"; 
			["size"] = 16;
			["function"] = SetFont;},
	 [5] = {["name"] = "18"; 
			["size"] = 18;
			["function"] = SetFont;},
	 [6] = {["name"] = "20"; 
			["size"] = 20;
			["function"] = SetFont;},		
   }
 }

local function pairsByKeys (Test1_Data, f)
	local a = {}
		for n in pairs(Test1_Data) do table.insert(a, n) end
		table.sort(a, f)
		local i = 0      -- iterator variable
		local iter = function ()   -- iterator function
			i = i + 1
			if a[i] == nil then return nil
			else return a[i], Test1_Data[a[i]]
			end
		end
	return iter
end
 
local info = {}

function Test1_DropDown_Initialize(self,level)
  info = wipe(info)
   level = level or 1;
   if (level == 1) then
     for key, subarray in pairsByKeys(Test1_Data) do
       info.hasArrow = true; 
       info.notCheckable = true;
       info.text = key;
       info.value = {
         ["Level1_Key"] = key;
       };
       UIDropDownMenu_AddButton(info, level);
     end 
   end 

	if (level == 2) then			
	local Level1_Key = UIDROPDOWNMENU_MENU_VALUE["Level1_Key"];
	subarray = Test1_Data[Level1_Key];
     for key, subsubarray in pairsByKeys(subarray) do
	   info.text = subsubarray["name"]
	   info.hasArrow = false; 
	   info.func = subsubarray["function"]
	   info.arg1 = subsubarray["path"]
	   info.arg2 = subsubarray["size"]
	   info.isNotRadio = true
	   
	   if info.arg1 then
		if info.arg1 == font or info.arg1 == texture then 
			info.checked = true
		else
			info.checked = false
		end
	   end
	   if info.arg2 then
		if info.arg2 ~= fontsize then
			info.checked = false
		else
			info.checked = true
		end
	   end
	    info.fontObject = subsubarray["font"]
		info.icon = subsubarray["path"] 
      info.value = {
         ["Level1_Key"] = Level1_Key;
         ["Sublevel_Key"] = key;
       };
	   UIDropDownMenu_AddButton(info, level);
     end 
   end 
end 

local dropdown = CreateFrame("Frame", "Test_DropDown", threatbar, "UIDropDownMenuTemplate");
UIDropDownMenu_Initialize(dropdown, Test1_DropDown_Initialize, "MENU");

threatbar:SetScript("OnMouseDown", function(s, button) 	
	if button == 'RightButton' then
		if not UnitAffectingCombat("player") then
			ToggleDropDownMenu(1, nil, dropdown, threatbar, 0, 0)
		end
	end
end)
